#!/usr/bin/gawk -f

BEGIN{
  pi = 3.1415926535;
  deg = pi/180.;
  arcsec = deg/3600.;
  mas = 1.e-3*arcsec;

  print "# JD (UTC) & one & two & x [arcsec] & y [arcsec] & major [arcsec] & minor [arcsec] & PA_ellipse [deg] & vardist [au] & l [deg] & b [deg] & dataset"
}
!/^#/ && (NF>0) && ($2 != "."){
  bessel = $1;
  phi = $2*deg;
  sigma_phi = $3*deg;
  rho = $4*arcsec;
  sigma_rho = $5*arcsec;

#  rho = $5*arcsec; sigma_rho = $6*arcsec;  # if additional character?

  if (sigma_phi < 1.0e-6*deg) { sigma_phi = 1.0*deg; }
  if (sigma_rho < 1.0e-6*arcsec) { sigma_rho = 0.01*arcsec; }

#  bessel = 1900.0 + (jd - 2415020.31352) / 365.242198781;
  jd = (bessel - 1900.0) * 365.242198781 + 2415020.31352;
  x = -rho*sin(phi);
  y = rho*cos(phi);
  major = sigma_rho;
  minor = rho*sigma_phi;
  PA_ellipse = phi;
  vardist = 0.0;
  l = 0.0;
  b = 0.0;
  one = 1;
  two = 3;
  dataset = "WDS";

  printf("%.6f	%d	%d	%.6f	%.6f	%.6f	%.6f	%.3f	%.10f	%.6f	%.6f	%s\n", jd, one, two, x/arcsec, y/arcsec, major/arcsec, minor/arcsec, PA_ellipse/deg, vardist, l, b, dataset);

}

